.. expect: default role used (hint: for inline literals, use double backticks) (default-role)
.. expect: default role used (hint: for inline literals, use double backticks) (default-role)

This is not detected: `foo`, `bar`.
